@@ -137,10 +137,10 @@ namespace caching {
 
 	bcache::validator::ptr superblock_validator();
 
-	superblock read_superblock(persistent_data::block_manager<>::ptr bm,
+	superblock read_superblock(persistent_data::block_manager::ptr bm,
 				   persistent_data::block_address location = SUPERBLOCK_LOCATION);
 
-	void write_superblock(persistent_data::block_manager<>::ptr bm,
+	void write_superblock(persistent_data::block_manager::ptr bm,
 			      superblock const &sb,
 			      persistent_data::block_address location = SUPERBLOCK_LOCATION);
 
@@ -148,7 +148,7 @@ namespace caching {
 			      persistent_data::block_address nr_metadata_blocks,
 			      superblock_damage::damage_visitor &visitor);
 
-	void check_superblock(persistent_data::block_manager<>::ptr bm,
+	void check_superblock(persistent_data::block_manager::ptr bm,
 			      persistent_data::block_address nr_metadata_blocks,
 			      superblock_damage::damage_visitor &visitor);
 }
