@@ -15,6 +15,7 @@
   (define-tool cache-dump)
   (define-tool cache-restore)
   (define-tool cache-metadata-size)
+  (define-tool cache-repair)
 
   (define-syntax with-cache-xml
     (syntax-rules ()
@@ -35,7 +36,8 @@
     (syntax-rules ()
       ((_ (md) b1 b2 ...)
        (with-temp-file-sized ((md "cache.bin" (to-bytes (meg 4))))
-         b1 b2 ...))))
+         (system (fmt #f "dd if=/usr/bin/ls of=" md " bs=4096 > /dev/null 2>&1"))
+           b1 b2 ...))))
 
   (define-syntax with-empty-metadata
     (syntax-rules ()
@@ -180,7 +182,7 @@
     "the input file can't be found"
     (with-empty-metadata (md)
       (run-fail-rcv (_ stderr) (cache-restore "-i no-such-file -o" md)
-        (assert-superblock-untouched md)
+        (assert-superblock-all-zeroes md)
         (assert-starts-with "Couldn't stat file" stderr))))
 
   (define-scenario (cache-restore garbage-input-file)
@@ -188,7 +190,7 @@
     (with-empty-metadata (md)
       (with-temp-file-sized ((xml "cache.xml" 4096))
         (run-fail-rcv (_ stderr) (cache-restore "-i" xml "-o" md)
-          (assert-superblock-untouched md)))))
+          (assert-superblock-all-zeroes md)))))
 
   (define-scenario (cache-restore missing-output-file)
     "the output file can't be found"
@@ -354,4 +356,28 @@
     (run-ok-rcv (stdout stderr) (cache-metadata-size "--nr-blocks 67108864")
       (assert-equal "3678208 sectors" stdout)
       (assert-eof stderr)))
+
+  ;;;-----------------------------------------------------------
+  ;;; cache_repair scenarios
+  ;;;-----------------------------------------------------------
+  (define-scenario (cache-repair missing-input-file)
+    "the input file can't be found"
+    (with-empty-metadata (md)
+      (run-fail-rcv (_ stderr) (cache-repair "-i no-such-file -o" md)
+        (assert-superblock-all-zeroes md)
+        (assert-starts-with "Couldn't stat path" stderr))))
+
+  (define-scenario (cache-repair garbage-input-file)
+    "the input file is just zeroes"
+    (with-empty-metadata (md1)
+      (with-corrupt-metadata (md2)
+        (run-fail-rcv (_ stderr) (cache-repair "-i" md1 "-o" md2)
+          (assert-superblock-all-zeroes md2)))))
+
+  (define-scenario (cache-repair missing-output-file)
+    "the output file can't be found"
+    (with-cache-xml (xml)
+      (run-fail-rcv (_ stderr) (cache-repair "-i" xml)
+        (assert-starts-with "No output file provided." stderr))))
+
 )
