@@ -54,6 +54,13 @@ namespace thin_provisioning {
 			  snapshotted_time_(0) {
 		}
 
+		device_details::device_details(uint64_t tid, uint32_t time)
+			: mapped_blocks_(0),
+			  transaction_id_(tid),
+			  creation_time_(time),
+			  snapshotted_time_(time) {
+		}
+
 		void
 		device_details_traits::unpack(device_details_disk const &disk, device_details &value)
 		{
@@ -89,18 +96,21 @@ namespace thin_provisioning {
 void
 thin_provisioning::walk_device_tree(device_tree const &tree,
 				    device_tree_detail::device_visitor &vv,
-				    device_tree_detail::damage_visitor &dv)
+				    device_tree_detail::damage_visitor &dv,
+                                    bool ignore_non_fatal)
 {
 	visitor_adapter av(vv);
 	ll_damage_visitor ll_dv(dv);
-	btree_visit_values(tree, av, ll_dv);
+	btree_visit_values(tree, av, ll_dv, ignore_non_fatal);
 }
 
 void
-thin_provisioning::check_device_tree(device_tree const &tree, damage_visitor &visitor)
+thin_provisioning::check_device_tree(device_tree const &tree,
+                                     damage_visitor &visitor,
+                                     bool ignore_non_fatal)
 {
 	noop_visitor vv;
-	walk_device_tree(tree, vv, visitor);
+	walk_device_tree(tree, vv, visitor, ignore_non_fatal);
 }
 
 //----------------------------------------------------------------
