@@ -20,7 +20,7 @@
 #include "thin-provisioning/metadata.h"
 
 #include "persistent-data/file_utils.h"
-#include "persistent-data/math_utils.h"
+#include "base/math_utils.h"
 #include "persistent-data/space-maps/core.h"
 #include "persistent-data/space-maps/disk.h"
 
@@ -33,8 +33,6 @@
 using namespace base;
 using namespace thin_provisioning;
 
-#define METADATA_VERSION 2
-
 //----------------------------------------------------------------
 
 namespace {
@@ -52,7 +50,7 @@ namespace {
 
 //----------------------------------------------------------------
 
-metadata::metadata(block_manager<>::ptr bm, open_type ot,
+metadata::metadata(block_manager::ptr bm, open_type ot,
 		   sector_t data_block_size,
 		   block_address nr_data_blocks)
 {
@@ -104,7 +102,7 @@ metadata::metadata(block_manager<>::ptr bm, open_type ot,
 	}
 }
 
-metadata::metadata(block_manager<>::ptr bm, bool read_space_maps)
+metadata::metadata(block_manager::ptr bm, bool read_space_maps)
 {
 	tm_ = open_tm(bm, SUPERBLOCK_LOCATION);
 	sb_ = read_superblock(tm_->get_bm(), SUPERBLOCK_LOCATION);
@@ -115,7 +113,7 @@ metadata::metadata(block_manager<>::ptr bm, bool read_space_maps)
 	open_btrees();
 }
 
-metadata::metadata(block_manager<>::ptr bm,
+metadata::metadata(block_manager::ptr bm,
 		   boost::optional<block_address> metadata_snap)
 {
 	tm_ = open_tm(bm, SUPERBLOCK_LOCATION);
@@ -126,7 +124,7 @@ metadata::metadata(block_manager<>::ptr bm,
 		throw runtime_error("no current metadata snap");
 
 	if (metadata_snap && *metadata_snap != actual_sb.metadata_snap_)
-			throw runtime_error("metadata snapshot does not match that in superblock");
+		throw runtime_error("metadata snapshot does not match that in superblock");
 
 	sb_ = read_superblock(bm, actual_sb.metadata_snap_);
 
@@ -134,7 +132,7 @@ metadata::metadata(block_manager<>::ptr bm,
 	open_btrees();
 }
 
-metadata::metadata(block_manager<>::ptr bm, superblock_detail::superblock const &sb)
+metadata::metadata(block_manager::ptr bm, superblock_detail::superblock const &sb)
 {
 	tm_ = open_tm(bm, SUPERBLOCK_LOCATION);
 	sb_ = sb;
