@@ -7,7 +7,7 @@
 //----------------------------------------------------------------
 
 namespace thin_provisioning {
-	void count_metadata(transaction_manager::ptr tm,
+	bool count_metadata(transaction_manager::ptr tm,
 			    superblock_detail::superblock const &sb,
 			    block_counter &bc,
 			    bool skip_metadata_snap = false);
