@@ -97,6 +97,7 @@ namespace thin_provisioning {
 
 		block_address const SUPERBLOCK_LOCATION = 0;
 		uint32_t const SUPERBLOCK_MAGIC = 27022010;
+		uint32_t const METADATA_VERSION = 2;
 
 		//--------------------------------
 
@@ -128,15 +129,18 @@ namespace thin_provisioning {
 
 	// FIXME: should we put init_superblock in here too?
 
-	superblock_detail::superblock read_superblock(persistent_data::block_manager<>::ptr bm);
-	superblock_detail::superblock read_superblock(persistent_data::block_manager<>::ptr bm,
+	// FIXME: make the bm const, and pass by reference rather than ptr
+	superblock_detail::superblock read_superblock(persistent_data::block_manager const &bm);
+	superblock_detail::superblock read_superblock(persistent_data::block_manager::ptr bm);
+	superblock_detail::superblock read_superblock(persistent_data::block_manager::ptr bm,
 						      persistent_data::block_address location);
 
-	void write_superblock(persistent_data::block_manager<>::ptr bm,
+	void write_superblock(persistent_data::block_manager::ptr bm,
 			      superblock_detail::superblock const &sb);
 
-	void check_superblock(persistent_data::block_manager<>::ptr bm,
-			      superblock_detail::damage_visitor &visitor);
+	void check_superblock(persistent_data::block_manager::ptr bm,
+			      superblock_detail::damage_visitor &visitor,
+                              persistent_data::block_address sb_location = superblock_detail::SUPERBLOCK_LOCATION);
 }
 
 //----------------------------------------------------------------
