@@ -6,13 +6,14 @@
 
 #include "version.h"
 
+#include "base/run.h"
 #include "persistent-data/data-structures/btree_damage_visitor.h"
-#include "persistent-data/run.h"
 #include "persistent-data/space-maps/core.h"
 #include "persistent-data/file_utils.h"
 #include "thin-provisioning/commands.h"
 #include "thin-provisioning/superblock.h"
 #include "thin-provisioning/mapping_tree.h"
+#include "thin-provisioning/metadata.h"
 #include "thin-provisioning/rmap_visitor.h"
 
 using namespace std;
@@ -21,23 +22,6 @@ using namespace thin_provisioning;
 //----------------------------------------------------------------
 
 namespace {
-	block_manager<>::ptr
-	open_bm(string const &path) {
-		block_address nr_blocks = get_nr_blocks(path);
-		block_manager<>::mode m = block_manager<>::READ_ONLY;
-		return block_manager<>::ptr(new block_manager<>(path, nr_blocks, 1, m));
-	}
-
-	transaction_manager::ptr
-	open_tm(block_manager<>::ptr bm) {
-		space_map::ptr sm(new core_map(bm->get_nr_blocks()));
-		sm->inc(superblock_detail::SUPERBLOCK_LOCATION);
-		transaction_manager::ptr tm(new transaction_manager(bm, sm));
-		return tm;
-	}
-
-	//--------------------------------
-
 	using namespace mapping_tree_detail;
 
 	typedef rmap_visitor::region region;
@@ -46,7 +30,7 @@ namespace {
 	class damage_visitor {
 	public:
 		virtual void visit(btree_path const &path, btree_detail::damage const &d) {
-			throw std::runtime_error("damage in mapping tree, please run thin_check");
+			throw std::runtime_error("Damage in mapping tree, please run thin_check.\n");
 		}
 	};
 
@@ -72,8 +56,9 @@ namespace {
 			for (it = regions.begin(); it != regions.end(); ++it)
 				rv.add_data_region(*it);
 
-			block_manager<>::ptr bm = open_bm(path);
-			transaction_manager::ptr tm = open_tm(bm);
+			block_manager::ptr bm = open_bm(path);
+			transaction_manager::ptr tm =
+				open_tm(bm, superblock_detail::SUPERBLOCK_LOCATION);
 
 			superblock_detail::superblock sb = read_superblock(bm);
 			mapping_tree mtree(*tm, sb.data_mapping_root_,
@@ -180,6 +165,12 @@ thin_rmap_cmd::run(int argc, char **argv)
 		exit(1);
 	}
 
+	if (!regions.size()) {
+		cerr << "No regions provided." << endl;
+		usage(cerr);
+		exit(1);
+	}
+
 	return rmap(argv[optind], regions);
 }
 
